# Changelog

<!--next-version-placeholder-->

## v0.3.0 (2021-03-19)
### Feature
* **drusen.py:** Added new histogram based DrusenFinder and made it the new default ([`9a3e667`](https://github.com/MedVisBonn/eyepy/commit/9a3e667ba721c2f16085b4f62225d1ee9ded078d))

## v0.2.6 (2021-03-12)
### Fix
* **base.py:** Fixed bugs for oat ([`7e10ab3`](https://github.com/MedVisBonn/eyepy/commit/7e10ab30e4ac9f7499ed16c00fe09c9567a83765))

## v0.2.5 (2021-02-11)
### Fix
* **docs:** Add requirements.txt for docs ([`8008c63`](https://github.com/MedVisBonn/eyepy/commit/8008c634bad246559c4b7d5b60b18749af5bfb30))

## v0.2.4 (2021-02-11)
### Fix
* **travis.yml:** Removed --user option ([`f68df9e`](https://github.com/MedVisBonn/eyepy/commit/f68df9ed6c7889923ea50573ad10e47140d9f80d))
* **travis.yml:** Switch to new pip version to properly resolve twine dependencies ([`7215226`](https://github.com/MedVisBonn/eyepy/commit/7215226c4ca2a78da8cbbfd73ef36a5322c7bb22))

## v0.2.3 (2021-02-11)
### Fix
* **docs:** Remove eyepy as requirement for building docs ([`05d6293`](https://github.com/MedVisBonn/eyepy/commit/05d6293382368f6cce42286193e6618f2518c5a6))

## v0.2.2 (2021-02-11)
### Fix
* **setup.py-eyepy/__init__.py:** Make sure the version numbers match ([`7357f11`](https://github.com/MedVisBonn/eyepy/commit/7357f11ad7f3af4466ccd03d8fe0f7f846c8915e))

## v0.2.1 (2021-02-11)
### Fix
* **core.drusen.py:** Use logging module instead of prints in this package ([`978fa11`](https://github.com/MedVisBonn/eyepy/commit/978fa11079cff23d7d8ffb423f3767858dfd6f2e))

## v0.2.0 (2021-02-11)
### Fix
* Changed enface to localizer in OCT object ([`bf6ecd2`](https://github.com/MedVisBonn/eyepy/commit/bf6ecd2d7e10bfbadf0e46c9115d0b908014b639))

### Breaking
*  ([`bf6ecd2`](https://github.com/MedVisBonn/eyepy/commit/bf6ecd2d7e10bfbadf0e46c9115d0b908014b639))
*  ([`09f8746`](https://github.com/MedVisBonn/eyepy/commit/09f8746538ef18cda473fdd0644c96a0094a9f68))

## v1.0.0 (2021-02-10)
### Breaking
*  ([`09f8746`](https://github.com/MedVisBonn/eyepy/commit/09f8746538ef18cda473fdd0644c96a0094a9f68))

## v0.1.6 (2021-02-10)
### Fix
* **.travis.yml:** Another fix ([`79e3332`](https://github.com/MedVisBonn/eyepy/commit/79e33325605f87205a1797cb232328ef8698c21d))
* **.travis.yml:** Fixed yaml problem ([`28eac5e`](https://github.com/MedVisBonn/eyepy/commit/28eac5e62684ce749cd45845465bc0fa6e443d2c))
* **ci-testing:** Test whether a fix triggers the travic ci build ([`718e9ee`](https://github.com/MedVisBonn/eyepy/commit/718e9ee612e3345c51e57036f9b51c15c5e1a9b4))

### Documentation
* **readme:** Added eyepy logo to readme.rst and removed readme.md ([`bc3e19d`](https://github.com/MedVisBonn/eyepy/commit/bc3e19d3120fa9a5329a6ad67ec9632a735d1d6e))
